@@ -2,18 +2,18 @@
  * Copyright (C) 2015 Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License version 3 as
+ * it under the terms of the GNU General Public License version 3 as
  * published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Lesser General Public License for more details.
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
+ * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Authored by: MichiHenning <michi@canonical.com>
+ * Authored by: Michi Henning <michi@canonical.com>
  */
 
 #pragma once
@@ -35,6 +35,12 @@ std::string read_file(std::string const& filename);
 // Write contents to filename.
 void write_file(std::string const& filename, std::string const& contents);
 
+// Write contents of in_fd to out_fd, using current read position of in_fd.
+void write_file(int in_fd, int out_fd);
+
+// Write contents of fd to path.
+void write_file(int in_fd, std::string const& path);
+
 // Return a temporary file name in TMPDIR.
 std::string create_tmp_filename();
 
